@@ -17,6 +17,7 @@ package apisix
 import (
 	"context"
 	"encoding/json"
+	"fmt"
 
 	"go.uber.org/zap"
 
@@ -61,34 +62,9 @@ func (u *upstreamClient) Get(ctx context.Context, name string) (*v1.Upstream, er
 		)
 	}
 
-	// TODO Add mutex here to avoid dog-pile effection.
-	url := u.url + "/" + uid
-	resp, err := u.cluster.getResource(ctx, url, "upstream")
+	// TODO Add mutex here to avoid dog-pile effect
+	ups, err = u.cluster.GetUpstream(ctx, u.url, uid)
 	if err != nil {
-		if err == cache.ErrNotFound {
-			log.Warnw("upstream not found",
-				zap.String("name", name),
-				zap.String("url", url),
-				zap.String("cluster", u.cluster.name),
-			)
-		} else {
-			log.Errorw("failed to get upstream from APISIX",
-				zap.String("name", name),
-				zap.String("url", url),
-				zap.String("cluster", u.cluster.name),
-				zap.Error(err),
-			)
-		}
-		return nil, err
-	}
-
-	ups, err = resp.upstream()
-	if err != nil {
-		log.Errorw("failed to convert upstream item",
-			zap.String("url", u.url),
-			zap.String("ssl_key", resp.Key),
-			zap.Error(err),
-		)
 		return nil, err
 	}
 
@@ -108,7 +84,6 @@ func (u *upstreamClient) List(ctx context.Context) ([]*v1.Upstream, error) {
 	)
 
 	upsItems, err := u.cluster.listResource(ctx, u.url, "upstream")
-	u.cluster.metricsCollector.IncrAPISIXRequest("upstream")
 	if err != nil {
 		log.Errorf("failed to list upstreams: %s", err)
 		return nil, err
@@ -131,7 +106,11 @@ func (u *upstreamClient) List(ctx context.Context) ([]*v1.Upstream, error) {
 	return items, nil
 }
 
-func (u *upstreamClient) Create(ctx context.Context, obj *v1.Upstream) (*v1.Upstream, error) {
+func (u *upstreamClient) Create(ctx context.Context, obj *v1.Upstream, shouldCompare bool) (*v1.Upstream, error) {
+	if v, skip := skipRequest(u.cluster, shouldCompare, u.url, obj.ID, obj); skip {
+		return v, nil
+	}
+
 	log.Debugw("try to create upstream",
 		zap.String("name", obj.Name),
 		zap.String("url", u.url),
@@ -153,7 +132,6 @@ func (u *upstreamClient) Create(ctx context.Context, obj *v1.Upstream) (*v1.Upst
 	log.Debugw("creating upstream", zap.ByteString("body", body), zap.String("url", url))
 
 	resp, err := u.cluster.createResource(ctx, url, "upstream", body)
-	u.cluster.metricsCollector.IncrAPISIXRequest("upstream")
 	if err != nil {
 		log.Errorf("failed to create upstream: %s", err)
 		return nil, err
@@ -166,6 +144,10 @@ func (u *upstreamClient) Create(ctx context.Context, obj *v1.Upstream) (*v1.Upst
 		log.Errorf("failed to reflect upstream create to cache: %s", err)
 		return nil, err
 	}
+	if err := u.cluster.generatedObjCache.InsertUpstream(obj); err != nil {
+		log.Errorf("failed to reflect generated upstream create to cache: %s", err)
+		return nil, err
+	}
 	return ups, err
 }
 
@@ -180,22 +162,30 @@ func (u *upstreamClient) Delete(ctx context.Context, obj *v1.Upstream) error {
 	if err := u.cluster.HasSynced(ctx); err != nil {
 		return err
 	}
+	url := u.url + "/" + obj.ID
+	if err := u.cluster.deleteResource(ctx, url, "upstream"); err != nil {
+		return err
+	}
 	if err := u.cluster.cache.DeleteUpstream(obj); err != nil {
 		log.Errorf("failed to reflect upstream delete to cache: %s", err.Error())
 		if err != cache.ErrNotFound {
 			return err
 		}
 	}
-	url := u.url + "/" + obj.ID
-	if err := u.cluster.deleteResource(ctx, url, "upstream"); err != nil {
-		u.cluster.metricsCollector.IncrAPISIXRequest("upstream")
-		return err
+	if err := u.cluster.generatedObjCache.DeleteUpstream(obj); err != nil {
+		log.Errorf("failed to reflect upstream delete to generated cache: %s", err.Error())
+		if err != cache.ErrNotFound {
+			return err
+		}
 	}
-	u.cluster.metricsCollector.IncrAPISIXRequest("upstream")
 	return nil
 }
 
-func (u *upstreamClient) Update(ctx context.Context, obj *v1.Upstream) (*v1.Upstream, error) {
+func (u *upstreamClient) Update(ctx context.Context, obj *v1.Upstream, shouldCompare bool) (*v1.Upstream, error) {
+	if v, skip := skipRequest(u.cluster, shouldCompare, u.url, obj.ID, obj); skip {
+		return v, nil
+	}
+
 	log.Debugw("try to update upstream",
 		zap.String("id", obj.ID),
 		zap.String("name", obj.Name),
@@ -217,7 +207,6 @@ func (u *upstreamClient) Update(ctx context.Context, obj *v1.Upstream) (*v1.Upst
 
 	url := u.url + "/" + obj.ID
 	resp, err := u.cluster.updateResource(ctx, url, "upstream", body)
-	u.cluster.metricsCollector.IncrAPISIXRequest("upstream")
 	if err != nil {
 		return nil, err
 	}
@@ -229,5 +218,133 @@ func (u *upstreamClient) Update(ctx context.Context, obj *v1.Upstream) (*v1.Upst
 		log.Errorf("failed to reflect upstream update to cache: %s", err)
 		return nil, err
 	}
+	if err := u.cluster.generatedObjCache.InsertUpstream(obj); err != nil {
+		log.Errorf("failed to reflect generated upstream update to cache: %s", err)
+		return nil, err
+	}
 	return ups, err
 }
+
+type upstreamMem struct {
+	url string
+
+	resource string
+	cluster  *cluster
+}
+
+func newUpstreamMem(c *cluster) Upstream {
+	return &upstreamMem{
+		url:      c.baseURL + "/upstreams",
+		resource: "upstreams",
+		cluster:  c,
+	}
+}
+
+func (r *upstreamMem) Get(ctx context.Context, name string) (*v1.Upstream, error) {
+	log.Debugw("try to look up upstream",
+		zap.String("name", name),
+		zap.String("cluster", r.cluster.name),
+	)
+	rid := id.GenID(name)
+	upstream, err := r.cluster.cache.GetUpstream(rid)
+	if err != nil {
+		if err != cache.ErrNotFound {
+			log.Errorw("failed to find upstream in cache",
+				zap.String("name", name),
+				zap.Error(err),
+			)
+		}
+		return nil, err
+	}
+	return upstream, nil
+}
+
+// List is only used in cache warming up. So here just pass through
+// to APISIX.
+func (r *upstreamMem) List(ctx context.Context) ([]*v1.Upstream, error) {
+	log.Debugw("try to list resource in APISIX",
+		zap.String("cluster", r.cluster.name),
+		zap.String("resource", r.resource),
+	)
+	upstreams, err := r.cluster.cache.ListUpstreams()
+	if err != nil {
+		log.Errorf("failed to list %s: %s", r.resource, err)
+		return nil, err
+	}
+	return upstreams, err
+}
+
+func (u *upstreamMem) Create(ctx context.Context, obj *v1.Upstream, shouldCompare bool) (*v1.Upstream, error) {
+	if shouldCompare && CompareResourceEqualFromCluster(u.cluster, obj.ID, obj) {
+		return obj, nil
+	}
+	data, err := json.Marshal(obj)
+	if err != nil {
+		return nil, err
+	}
+	if err := u.cluster.upstreamServiceRelation.Create(ctx, obj.Name); err != nil {
+		log.Errorf("failed to reflect upstreamService create to cache: %s", err)
+	}
+	u.cluster.CreateResource(u.resource, obj.ID, data)
+	if err := u.cluster.cache.InsertUpstream(obj); err != nil {
+		log.Errorf("failed to reflect upstream create to cache: %s", err)
+		return nil, err
+	}
+	return obj, nil
+}
+
+func (u *upstreamMem) Delete(ctx context.Context, obj *v1.Upstream) error {
+	if ok, err := u.deleteCheck(ctx, obj); !ok {
+		log.Debug("failed to delete upstream", zap.Error(err))
+		return cache.ErrStillInUse
+	}
+	data, err := json.Marshal(obj)
+	if err != nil {
+		return err
+	}
+	u.cluster.DeleteResource(u.resource, obj.ID, data)
+	if err := u.cluster.cache.DeleteUpstream(obj); err != nil {
+		log.Errorf("failed to reflect upstream delete to cache: %s", err)
+		return err
+	}
+	return nil
+}
+
+func (u *upstreamMem) Update(ctx context.Context, obj *v1.Upstream, shouldCompare bool) (*v1.Upstream, error) {
+	if shouldCompare && CompareResourceEqualFromCluster(u.cluster, obj.ID, obj) {
+		return obj, nil
+	}
+	data, err := json.Marshal(obj)
+	if err != nil {
+		return nil, err
+	}
+	if err := u.cluster.upstreamServiceRelation.Create(ctx, obj.Name); err != nil {
+		log.Errorf("failed to reflect upstreamService update to cache: %s", err)
+	}
+	u.cluster.UpdateResource(u.resource, obj.ID, data)
+	if err := u.cluster.cache.InsertUpstream(obj); err != nil {
+		log.Errorf("failed to reflect upstream update to cache: %s", err)
+		return nil, err
+	}
+	return obj, nil
+}
+
+// TODO: Maintain a reference count for each object without having to poll each time
+func (u *upstreamMem) deleteCheck(ctx context.Context, obj *v1.Upstream) (bool, error) {
+	routes, _ := u.cluster.route.List(ctx)
+	sroutes, _ := u.cluster.cache.ListStreamRoutes()
+	if routes == nil && sroutes == nil {
+		return true, nil
+	}
+	for _, route := range routes {
+		if route.UpstreamId == obj.ID {
+			return false, fmt.Errorf("can not delete this upstream, route.id=%s is still using it now", route.ID)
+		}
+	}
+	for _, sroute := range sroutes {
+		if sroute.UpstreamId == obj.ID {
+			return false, fmt.Errorf("can not delete this upstream, stream_route.id=%s is still using it now", sroute.ID)
+		}
+	}
+	return true, nil
+}
