@@ -47,8 +47,6 @@ const (
 	// WARNING: ingress.extensions/v1beta1 is deprecated in v1.14+, and will be unavilable
 	// in v1.22.
 	IngressExtensionsV1beta1 = "extensions/v1beta1"
-	// ApisixV2beta3 represents apisix.apache.org/v2beta3
-	ApisixV2beta3 = "apisix.apache.org/v2beta3"
 	// ApisixV2 represents apisix.apache.org/v2
 	ApisixV2 = "apisix.apache.org/v2"
 	// DefaultAPIVersion refers to the default resource version
@@ -59,46 +57,64 @@ const (
 	// ControllerName is the name of the controller used to identify
 	// the controller of the GatewayClass.
 	ControllerName = "apisix.apache.org/gateway-controller"
+
+	// Process Ingress resources with ingressClass=apisix and all CRDs
+	IngressClassApisixAndAll = "apisix-and-all"
+
+	// Deployment mode
+	DeploymentMode_AdminAPI = "admin-api"
+	DeploymentMode_gRPC     = "grpc"
 )
 
 var (
 	// Description information of API version, including default values and supported API version.
-	APIVersionDescribe = fmt.Sprintf(`the default value of API version is "%s", support "%s" and "%s".`, DefaultAPIVersion, ApisixV2beta3, ApisixV2)
+	APIVersionDescribe = fmt.Sprintf(`the default value of API version is "%s", support "%s".`, DefaultAPIVersion, ApisixV2)
 )
 
 // Config contains all config items which are necessary for
 // apisix-ingress-controller's running.
 type Config struct {
-	CertFilePath               string             `json:"cert_file" yaml:"cert_file"`
-	KeyFilePath                string             `json:"key_file" yaml:"key_file"`
-	LogLevel                   string             `json:"log_level" yaml:"log_level"`
-	LogOutput                  string             `json:"log_output" yaml:"log_output"`
-	LogRotateOutputPath        string             `json:"log_rotate_output_path" yaml:"log_rotate_output_path"`
-	LogRotationMaxSize         int                `json:"log_rotation_max_size" yaml:"log_rotation_max_size"`
-	LogRotationMaxAge          int                `json:"log_rotation_max_age" yaml:"log_rotation_max_age"`
-	LogRotationMaxBackups      int                `json:"log_rotation_max_backups" yaml:"log_rotation_max_backups"`
-	HTTPListen                 string             `json:"http_listen" yaml:"http_listen"`
-	HTTPSListen                string             `json:"https_listen" yaml:"https_listen"`
-	IngressPublishService      string             `json:"ingress_publish_service" yaml:"ingress_publish_service"`
-	IngressStatusAddress       []string           `json:"ingress_status_address" yaml:"ingress_status_address"`
-	EnableProfiling            bool               `json:"enable_profiling" yaml:"enable_profiling"`
-	Kubernetes                 KubernetesConfig   `json:"kubernetes" yaml:"kubernetes"`
-	APISIX                     APISIXConfig       `json:"apisix" yaml:"apisix"`
-	ApisixResourceSyncInterval types.TimeDuration `json:"apisix-resource-sync-interval" yaml:"apisix-resource-sync-interval"`
-	PluginMetadataConfigMap    string             `json:"plugin_metadata_cm" yaml:"plugin_metadata_cm"`
+	CertFilePath                 string             `json:"cert_file" yaml:"cert_file"`
+	KeyFilePath                  string             `json:"key_file" yaml:"key_file"`
+	LogLevel                     string             `json:"log_level" yaml:"log_level"`
+	LogOutput                    string             `json:"log_output" yaml:"log_output"`
+	LogRotateOutputPath          string             `json:"log_rotate_output_path" yaml:"log_rotate_output_path"`
+	LogRotationMaxSize           int                `json:"log_rotation_max_size" yaml:"log_rotation_max_size"`
+	LogRotationMaxAge            int                `json:"log_rotation_max_age" yaml:"log_rotation_max_age"`
+	LogRotationMaxBackups        int                `json:"log_rotation_max_backups" yaml:"log_rotation_max_backups"`
+	HTTPListen                   string             `json:"http_listen" yaml:"http_listen"`
+	HTTPSListen                  string             `json:"https_listen" yaml:"https_listen"`
+	IngressPublishService        string             `json:"ingress_publish_service" yaml:"ingress_publish_service"`
+	IngressStatusAddress         []string           `json:"ingress_status_address" yaml:"ingress_status_address"`
+	EnableProfiling              bool               `json:"enable_profiling" yaml:"enable_profiling"`
+	Kubernetes                   KubernetesConfig   `json:"kubernetes" yaml:"kubernetes"`
+	APISIX                       APISIXConfig       `json:"apisix" yaml:"apisix"`
+	ApisixResourceSyncInterval   types.TimeDuration `json:"apisix_resource_sync_interval" yaml:"apisix_resource_sync_interval"`
+	ApisixResourceSyncComparison bool               `json:"apisix_resource_sync_comparison" yaml:"apisix_resource_sync_comparison"`
+	PluginMetadataConfigMap      string             `json:"plugin_metadata_cm" yaml:"plugin_metadata_cm"`
+	EtcdServer                   EtcdServerConfig   `json:"etcdserver" yaml:"etcdserver"`
+}
+
+type EtcdServerConfig struct {
+	Enabled           bool   `json:"enabled" yaml:"enabled"`
+	Prefix            string `json:"prefix" yaml:"prefix"`
+	ListenAddress     string `json:"listen_address" yaml:"listen_address"`
+	SSLKeyEncryptSalt string `json:"ssl_key_encrypt_salt" yaml:"ssl_key_encrypt_salt"`
 }
 
 // KubernetesConfig contains all Kubernetes related config items.
 type KubernetesConfig struct {
-	Kubeconfig          string             `json:"kubeconfig" yaml:"kubeconfig"`
-	ResyncInterval      types.TimeDuration `json:"resync_interval" yaml:"resync_interval"`
-	NamespaceSelector   []string           `json:"namespace_selector" yaml:"namespace_selector"`
-	ElectionID          string             `json:"election_id" yaml:"election_id"`
-	IngressClass        string             `json:"ingress_class" yaml:"ingress_class"`
-	IngressVersion      string             `json:"ingress_version" yaml:"ingress_version"`
-	WatchEndpointSlices bool               `json:"watch_endpoint_slices" yaml:"watch_endpoint_slices"`
-	APIVersion          string             `json:"api_version" yaml:"api_version"`
-	EnableGatewayAPI    bool               `json:"enable_gateway_api" yaml:"enable_gateway_api"`
+	Kubeconfig           string             `json:"kubeconfig" yaml:"kubeconfig"`
+	ResyncInterval       types.TimeDuration `json:"resync_interval" yaml:"resync_interval"`
+	NamespaceSelector    []string           `json:"namespace_selector" yaml:"namespace_selector"`
+	ElectionID           string             `json:"election_id" yaml:"election_id"`
+	IngressClass         string             `json:"ingress_class" yaml:"ingress_class"`
+	IngressVersion       string             `json:"ingress_version" yaml:"ingress_version"`
+	WatchEndpointSlices  bool               `json:"watch_endpoint_slices" yaml:"watch_endpoint_slices"`
+	APIVersion           string             `json:"api_version" yaml:"api_version"`
+	EnableGatewayAPI     bool               `json:"enable_gateway_api" yaml:"enable_gateway_api"`
+	DisableStatusUpdates bool               `json:"disable_status_updates" yaml:"disable_status_updates"`
+	EnableAdmission      bool               `json:"enable_admission" yaml:"enable_admission"`
 }
 
 // APISIXConfig contains all APISIX related config items.
@@ -118,34 +134,43 @@ type APISIXConfig struct {
 // default value.
 func NewDefaultConfig() *Config {
 	return &Config{
-		LogLevel:                   "warn",
-		LogOutput:                  "stderr",
-		LogRotateOutputPath:        "",
-		LogRotationMaxSize:         100,
-		LogRotationMaxAge:          0,
-		LogRotationMaxBackups:      0,
-		HTTPListen:                 ":8080",
-		HTTPSListen:                ":8443",
-		IngressPublishService:      "",
-		IngressStatusAddress:       []string{},
-		CertFilePath:               "/etc/webhook/certs/cert.pem",
-		KeyFilePath:                "/etc/webhook/certs/key.pem",
-		EnableProfiling:            true,
-		ApisixResourceSyncInterval: types.TimeDuration{Duration: 300 * time.Second},
+		LogLevel:                     "warn",
+		LogOutput:                    "stderr",
+		LogRotateOutputPath:          "",
+		LogRotationMaxSize:           100,
+		LogRotationMaxAge:            0,
+		LogRotationMaxBackups:        0,
+		HTTPListen:                   ":8080",
+		HTTPSListen:                  ":8443",
+		IngressPublishService:        "",
+		IngressStatusAddress:         []string{},
+		CertFilePath:                 "/etc/webhook/certs/cert.pem",
+		KeyFilePath:                  "/etc/webhook/certs/key.pem",
+		EnableProfiling:              true,
+		ApisixResourceSyncInterval:   types.TimeDuration{Duration: 1 * time.Hour},
+		ApisixResourceSyncComparison: true,
 		Kubernetes: KubernetesConfig{
-			Kubeconfig:          "", // Use in-cluster configurations.
-			ResyncInterval:      types.TimeDuration{Duration: 6 * time.Hour},
-			ElectionID:          IngressAPISIXLeader,
-			IngressClass:        IngressClass,
-			IngressVersion:      IngressNetworkingV1,
-			APIVersion:          DefaultAPIVersion,
-			WatchEndpointSlices: false,
-			EnableGatewayAPI:    false,
+			Kubeconfig:           "", // Use in-cluster configurations.
+			ResyncInterval:       types.TimeDuration{Duration: 6 * time.Hour},
+			ElectionID:           IngressAPISIXLeader,
+			IngressClass:         IngressClassApisixAndAll,
+			IngressVersion:       IngressNetworkingV1,
+			APIVersion:           DefaultAPIVersion,
+			WatchEndpointSlices:  false,
+			EnableGatewayAPI:     false,
+			DisableStatusUpdates: false,
+			EnableAdmission:      false,
 		},
 		APISIX: APISIXConfig{
 			AdminAPIVersion:    "v2",
 			DefaultClusterName: "default",
 		},
+		EtcdServer: EtcdServerConfig{
+			Enabled:           false,
+			Prefix:            "/apisix",
+			ListenAddress:     ":12379",
+			SSLKeyEncryptSalt: "edd1c9f0985e76a2",
+		},
 	}
 }
 
@@ -200,7 +225,7 @@ func (cfg *Config) Validate() error {
 		return errors.New("apisix base url is required")
 	}
 	switch cfg.Kubernetes.IngressVersion {
-	case IngressNetworkingV1, IngressNetworkingV1beta1, IngressExtensionsV1beta1:
+	case IngressNetworkingV1, IngressNetworkingV1beta1:
 		break
 	default:
 		return errors.New("unsupported ingress version")
