@@ -18,8 +18,8 @@ package id
 import (
 	"fmt"
 	"hash/crc32"
-	"reflect"
-	"unsafe"
+
+	"github.com/apache/apisix-ingress-controller/pkg/utils"
 )
 
 // GenID generates an ID according to the raw material.
@@ -27,12 +27,7 @@ func GenID(raw string) string {
 	if raw == "" {
 		return ""
 	}
-	sh := &reflect.SliceHeader{
-		Data: (*reflect.StringHeader)(unsafe.Pointer(&raw)).Data,
-		Len:  len(raw),
-		Cap:  len(raw),
-	}
-	p := *(*[]byte)(unsafe.Pointer(sh))
+	p := utils.String2Byte(raw)
 
 	res := crc32.ChecksumIEEE(p)
 	return fmt.Sprintf("%x", res)
