@@ -17,18 +17,16 @@ package kube
 import (
 	"errors"
 
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+
 	"github.com/apache/apisix-ingress-controller/pkg/config"
 	configv2 "github.com/apache/apisix-ingress-controller/pkg/kube/apisix/apis/config/v2"
-	configv2beta3 "github.com/apache/apisix-ingress-controller/pkg/kube/apisix/apis/config/v2beta3"
 	listersv2 "github.com/apache/apisix-ingress-controller/pkg/kube/apisix/client/listers/config/v2"
-	listersv2beta3 "github.com/apache/apisix-ingress-controller/pkg/kube/apisix/client/listers/config/v2beta3"
 )
 
 // ApisixPluginConfigLister is an encapsulation for the lister of ApisixPluginConfig,
 // it aims at to be compatible with different ApisixPluginConfig versions.
 type ApisixPluginConfigLister interface {
-	// V2beta3 gets the ApisixPluginConfig in apisix.apache.org/v2beta3.
-	V2beta3(string, string) (ApisixPluginConfig, error)
 	// V2 gets the ApisixPluginConfig in apisix.apache.org/v2.
 	V2(string, string) (ApisixPluginConfig, error)
 }
@@ -45,15 +43,14 @@ type ApisixPluginConfig interface {
 	// GroupVersion returns the api group version of the
 	// real ApisixPluginConfig.
 	GroupVersion() string
-	// V2beta3 returns the ApisixPluginConfig in apisix.apache.org/v2beta3, the real
-	// ApisixPluginConfig must be in this group version, otherwise will panic.
-	V2beta3() *configv2beta3.ApisixPluginConfig
 	// V2 returns the ApisixPluginConfig in apisix.apache.org/v2, the real
 	// ApisixPluginConfig must be in this group version, otherwise will panic.
 	V2() *configv2.ApisixPluginConfig
 	// ResourceVersion returns the the resource version field inside
 	// the real ApisixPluginConfig.
 	ResourceVersion() string
+
+	metav1.Object
 }
 
 // ApisixPluginConfigEvent contains the ApisixPluginConfig key (namespace/name)
@@ -66,15 +63,8 @@ type ApisixPluginConfigEvent struct {
 
 type apisixPluginConfig struct {
 	groupVersion string
-	v2beta3      *configv2beta3.ApisixPluginConfig
 	v2           *configv2.ApisixPluginConfig
-}
-
-func (apc *apisixPluginConfig) V2beta3() *configv2beta3.ApisixPluginConfig {
-	if apc.groupVersion != config.ApisixV2beta3 {
-		panic("not a apisix.apache.org/v2beta3 pluginConfig")
-	}
-	return apc.v2beta3
+	metav1.Object
 }
 
 func (apc *apisixPluginConfig) V2() *configv2.ApisixPluginConfig {
@@ -89,26 +79,11 @@ func (apc *apisixPluginConfig) GroupVersion() string {
 }
 
 func (apc *apisixPluginConfig) ResourceVersion() string {
-	if apc.groupVersion == config.ApisixV2beta3 {
-		return apc.V2beta3().ResourceVersion
-	}
 	return apc.V2().ResourceVersion
 }
 
 type apisixPluginConfigLister struct {
-	v2beta3Lister listersv2beta3.ApisixPluginConfigLister
-	v2Lister      listersv2.ApisixPluginConfigLister
-}
-
-func (l *apisixPluginConfigLister) V2beta3(namespace, name string) (ApisixPluginConfig, error) {
-	apc, err := l.v2beta3Lister.ApisixPluginConfigs(namespace).Get(name)
-	if err != nil {
-		return nil, err
-	}
-	return &apisixPluginConfig{
-		groupVersion: config.ApisixV2beta3,
-		v2beta3:      apc,
-	}, nil
+	v2Lister listersv2.ApisixPluginConfigLister
 }
 
 func (l *apisixPluginConfigLister) V2(namespace, name string) (ApisixPluginConfig, error) {
@@ -119,6 +94,7 @@ func (l *apisixPluginConfigLister) V2(namespace, name string) (ApisixPluginConfi
 	return &apisixPluginConfig{
 		groupVersion: config.ApisixV2,
 		v2:           apc,
+		Object:       apc,
 	}, nil
 }
 
@@ -126,15 +102,11 @@ func (l *apisixPluginConfigLister) V2(namespace, name string) (ApisixPluginConfi
 // type of obj.
 func MustNewApisixPluginConfig(obj interface{}) ApisixPluginConfig {
 	switch apc := obj.(type) {
-	case *configv2beta3.ApisixPluginConfig:
-		return &apisixPluginConfig{
-			groupVersion: config.ApisixV2beta3,
-			v2beta3:      apc,
-		}
 	case *configv2.ApisixPluginConfig:
 		return &apisixPluginConfig{
 			groupVersion: config.ApisixV2,
 			v2:           apc,
+			Object:       apc,
 		}
 	default:
 		panic("invalid ApisixPluginConfig type")
@@ -146,24 +118,19 @@ func MustNewApisixPluginConfig(obj interface{}) ApisixPluginConfig {
 // type assertion fails.
 func NewApisixPluginConfig(obj interface{}) (ApisixPluginConfig, error) {
 	switch apc := obj.(type) {
-	case *configv2beta3.ApisixPluginConfig:
-		return &apisixPluginConfig{
-			groupVersion: config.ApisixV2beta3,
-			v2beta3:      apc,
-		}, nil
 	case *configv2.ApisixPluginConfig:
 		return &apisixPluginConfig{
 			groupVersion: config.ApisixV2,
 			v2:           apc,
+			Object:       apc,
 		}, nil
 	default:
 		return nil, errors.New("invalid ApisixPluginConfig type")
 	}
 }
 
-func NewApisixPluginConfigLister(v2beta3 listersv2beta3.ApisixPluginConfigLister, v2 listersv2.ApisixPluginConfigLister) ApisixPluginConfigLister {
+func NewApisixPluginConfigLister(v2 listersv2.ApisixPluginConfigLister) ApisixPluginConfigLister {
 	return &apisixPluginConfigLister{
-		v2beta3Lister: v2beta3,
-		v2Lister:      v2,
+		v2Lister: v2,
 	}
 }
