@@ -18,6 +18,7 @@ import (
 	"context"
 	"fmt"
 	"reflect"
+	"strconv"
 	"sync"
 	"time"
 
@@ -326,7 +327,9 @@ func (c *apisixTlsController) onUpdate(oldObj, newObj interface{}) {
 		log.Errorw("found ApisixTls resource with bad type", zap.Error(err))
 		return
 	}
-	if prev.ResourceVersion() >= curr.ResourceVersion() {
+	oldRV, _ := strconv.ParseInt(prev.ResourceVersion(), 0, 64)
+	newRV, _ := strconv.ParseInt(curr.ResourceVersion(), 0, 64)
+	if oldRV >= newRV {
 		return
 	}
 	// Updates triggered by status are ignored.
@@ -405,7 +408,9 @@ func (c *apisixTlsController) onDelete(obj interface{}) {
 	c.MetricsCollector.IncrEvents("TLS", "delete")
 }
 
-func (c *apisixTlsController) ResourceSync(interval time.Duration) {
+// ResourceSync syncs ApisixTls resources within namespace to workqueue.
+// If namespace is "", it syncs all namespaces ApisixTls resources.
+func (c *apisixTlsController) ResourceSync(interval time.Duration, namespace string) {
 	objs := c.ApisixTlsInformer.GetIndexer().List()
 	delay := GetSyncDelay(interval, len(objs))
 
@@ -418,6 +423,17 @@ func (c *apisixTlsController) ResourceSync(interval time.Duration) {
 		if !c.namespaceProvider.IsWatchingNamespace(key) {
 			continue
 		}
+		ns, _, err := cache.SplitMetaNamespaceKey(key)
+		if err != nil {
+			log.Errorw("split ApisixRoute meta key failed",
+				zap.Error(err),
+				zap.String("key", key),
+			)
+			continue
+		}
+		if namespace != "" && ns != namespace {
+			continue
+		}
 		tls, err := kube.NewApisixTls(obj)
 		if err != nil {
 			log.Errorw("ApisixTls sync failed, found ApisixTls resource with bad type", zap.Error(err))
