@@ -19,6 +19,9 @@ package translation
 import (
 	"bytes"
 	"context"
+	"crypto/sha1"
+	"encoding/base64"
+	"encoding/json"
 	"fmt"
 	"strings"
 
@@ -42,6 +45,12 @@ import (
 	apisixv1 "github.com/apache/apisix-ingress-controller/pkg/types/apisix/v1"
 )
 
+const (
+	// We omit vowels from the set of available characters to reduce the chances
+	// of "bad words" being formed.
+	alphanums = "bcdfghjklmnpqrstvwxz2456789"
+)
+
 type TranslatorOptions struct {
 	Apisix      apisix.APISIX
 	ClusterName string
@@ -81,14 +90,13 @@ func NewIngressTranslator(opts *TranslatorOptions,
 	return t
 }
 
-func (t *translator) TranslateIngressTLS(namespace, ingName, secretName string, hosts []string) (*apisixv1.Ssl, error) {
+func createApisixTLS(namespace, ingName, secretName string, hosts []string) (kubev2.ApisixTls, error) {
 	apisixTls := kubev2.ApisixTls{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "ApisixTls",
 			APIVersion: "apisix.apache.org/v1",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      fmt.Sprintf("%v-%v", ingName, "tls"),
 			Namespace: namespace,
 		},
 		Spec: &kubev2.ApisixTlsSpec{
@@ -101,8 +109,24 @@ func (t *translator) TranslateIngressTLS(namespace, ingName, secretName string,
 	for _, host := range hosts {
 		apisixTls.Spec.Hosts = append(apisixTls.Spec.Hosts, kubev2.HostType(host))
 	}
+	tlsByt, err := json.Marshal(apisixTls)
+	if err != nil {
+		return apisixTls, fmt.Errorf("failed to marshal Apisix TLS: %s", err.Error())
+	}
+	hasher := sha1.New()
+	hasher.Write(tlsByt)
+	uniqueHash := SafeEncodeString(base64.URLEncoding.EncodeToString(hasher.Sum(nil)), 6)
+	//The name has to be unique per namespace or the IDs generated for Apisix SSL objects will collide
+	apisixTls.ObjectMeta.Name = fmt.Sprintf("%v-%v-%v", ingName, "tls", uniqueHash)
+	return apisixTls, nil
+}
 
-	return t.ApisixTranslator.TranslateSSLV2(&apisixTls)
+func (t *translator) TranslateIngressTLS(namespace, ingName, secretName string, hosts []string) (*apisixv1.Ssl, error) {
+	apisixTLS, err := createApisixTLS(namespace, ingName, secretName, hosts)
+	if err != nil {
+		return nil, err
+	}
+	return t.ApisixTranslator.TranslateSSLV2(&apisixTLS)
 }
 
 func (t *translator) TranslateIngress(ing kube.Ingress, args ...bool) (*translation.TranslateContext, error) {
@@ -177,8 +201,28 @@ func (t *translator) translateIngressV1(ing *networkingv1.Ingress, skipVerify bo
 						return nil, err
 					}
 				}
-				if ingress.UpstreamScheme != "" {
-					ups.Scheme = ingress.UpstreamScheme
+				if ingress.Upstream.Scheme != "" {
+					ups.Scheme = ingress.Upstream.Scheme
+				}
+				if ingress.Upstream.Retry > 0 {
+					retry := ingress.Upstream.Retry
+					ups.Retries = &retry
+				}
+				if ups.Timeout == nil {
+					ups.Timeout = &apisixv1.UpstreamTimeout{
+						Read:    60,
+						Send:    60,
+						Connect: 60,
+					}
+				}
+				if ingress.Upstream.TimeoutConnect > 0 {
+					ups.Timeout.Connect = ingress.Upstream.TimeoutConnect
+				}
+				if ingress.Upstream.TimeoutRead > 0 {
+					ups.Timeout.Read = ingress.Upstream.TimeoutRead
+				}
+				if ingress.Upstream.TimeoutSend > 0 {
+					ups.Timeout.Send = ingress.Upstream.TimeoutSend
 				}
 				ctx.AddUpstream(ups)
 			}
@@ -282,8 +326,8 @@ func (t *translator) translateIngressV1beta1(ing *networkingv1beta1.Ingress, ski
 						return nil, err
 					}
 				}
-				if ingress.UpstreamScheme != "" {
-					ups.Scheme = ingress.UpstreamScheme
+				if ingress.Upstream.Scheme != "" {
+					ups.Scheme = ingress.Upstream.Scheme
 				}
 				ctx.AddUpstream(ups)
 			}
@@ -335,7 +379,26 @@ func (t *translator) translateIngressV1beta1(ing *networkingv1beta1.Ingress, ski
 			if len(ingress.Plugins) > 0 {
 				route.Plugins = *(ingress.Plugins.DeepCopy())
 			}
-
+			if ingress.Upstream.Retry > 0 {
+				retry := ingress.Upstream.Retry
+				ups.Retries = &retry
+			}
+			if ups.Timeout == nil {
+				ups.Timeout = &apisixv1.UpstreamTimeout{
+					Read:    60,
+					Send:    60,
+					Connect: 60,
+				}
+			}
+			if ingress.Upstream.TimeoutConnect > 0 {
+				ups.Timeout.Connect = ingress.Upstream.TimeoutConnect
+			}
+			if ingress.Upstream.TimeoutRead > 0 {
+				ups.Timeout.Read = ingress.Upstream.TimeoutRead
+			}
+			if ingress.Upstream.TimeoutSend > 0 {
+				ups.Timeout.Send = ingress.Upstream.TimeoutSend
+			}
 			if ingress.PluginConfigName != "" {
 				route.PluginConfigId = id.GenID(apisixv1.ComposePluginConfigName(ing.Namespace, ingress.PluginConfigName))
 			}
@@ -470,8 +533,12 @@ func (t *translator) TranslateOldIngress(ing kube.Ingress) (*translation.Transla
 func (t *translator) translateOldIngressTLS(namespace, ingName, secretName string, hosts []string) (*apisixv1.Ssl, error) {
 	ssl, err := t.TranslateIngressTLS(namespace, ingName, secretName, hosts)
 	if err != nil && k8serrors.IsNotFound(err) {
+		apisixTLS, err := createApisixTLS(namespace, ingName, secretName, hosts)
+		if err != nil {
+			return nil, err
+		}
 		return &apisixv1.Ssl{
-			ID: id.GenID(namespace + "_" + fmt.Sprintf("%v-%v", ingName, "tls")),
+			ID: id.GenID(namespace + "_" + apisixTLS.Name),
 		}, nil
 	}
 	return ssl, err
@@ -573,3 +640,17 @@ func composeIngressRouteName(namespace, name, host, path string) string {
 
 	return buf.String()
 }
+
+// This reduces the chances of bad words and
+// ensures that strings generated from hash functions appear consistent throughout the API.
+// The returned string doesn't exceed the size limit
+func SafeEncodeString(s string, limit int) string {
+	r := make([]byte, len(s))
+	for i, b := range []rune(s) {
+		if i == limit {
+			break
+		}
+		r[i] = alphanums[(int(b) % len(alphanums))]
+	}
+	return string(r)
+}
